[![Build Status](https://travis-ci.org/koralarts/django-advert.svg?branch=master)](https://travis-ci.org/koralarts/django-advert) [![License](https://img.shields.io/badge/license-MIT-brightgreen.svg?style=flat)](http://opensource.org/licenses/MIT)

django-advert
=============

A simple advertising Module for Django

## Installation

Install via pip:
```
pip install django-advert
```

Add to `Installed Apps`
```
INSTALLED_APPS = (
  ...
  advert,
  ...
)
```
